# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.1.0

import enum
import typing
import uuid as _uuid

import winrt.system
from winrt import _winrt_windows_ui_xaml_interop

__all__ = [
    "NotifyCollectionChangedAction",
    "TypeKind",
    "TypeName",
    "NotifyCollectionChangedEventArgs",
    "IBindableIterable",
    "IBindableIterator",
    "IBindableObservableVector",
    "IBindableVector",
    "IBindableVectorView",
    "INotifyCollectionChanged",
    "BindableVectorChangedEventHandler",
    "NotifyCollectionChangedEventHandler",
]

class NotifyCollectionChangedAction(enum.IntEnum):
    ADD = 0
    REMOVE = 1
    REPLACE = 2
    MOVE = 3
    RESET = 4

class TypeKind(enum.IntEnum):
    PRIMITIVE = 0
    METADATA = 1
    CUSTOM = 2

TypeName = _winrt_windows_ui_xaml_interop.TypeName
NotifyCollectionChangedEventArgs = _winrt_windows_ui_xaml_interop.NotifyCollectionChangedEventArgs
IBindableIterable = _winrt_windows_ui_xaml_interop.IBindableIterable
IBindableIterator = _winrt_windows_ui_xaml_interop.IBindableIterator
IBindableObservableVector = _winrt_windows_ui_xaml_interop.IBindableObservableVector
IBindableVector = _winrt_windows_ui_xaml_interop.IBindableVector
IBindableVectorView = _winrt_windows_ui_xaml_interop.IBindableVectorView
INotifyCollectionChanged = _winrt_windows_ui_xaml_interop.INotifyCollectionChanged
BindableVectorChangedEventHandler = typing.Callable[[typing.Optional[IBindableObservableVector], typing.Optional[winrt.system.Object]], None]
NotifyCollectionChangedEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[NotifyCollectionChangedEventArgs]], None]
